@@ -14,10 +14,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifdef Q_WS_MAEMO_5
-#include <libosso.h>
-#endif
-
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QDataStream>
@@ -25,30 +21,50 @@
 #include <QLayout>
 #include <QInputDialog>
 #include <QTextCodec>
+#include <QDir>
 
 #include <assert.h>
 #include <sstream>
 #include <iomanip>
 #include <iostream>
+#include <fstream>
 
 #include "mainwindow.h"
 #include "aboutdialog.hpp"
 #include "showfulllistdialog.hpp"
 
+//#define MCE_SCREENSAVER_HANDLING
+#define QT_SCREENSAVER_HANDLING
+#ifdef MCE_SCREENSAVER_HANDLING
+#ifdef Q_WS_MAEMO_5
+#include <QtDBus/QtDBus>
+#include <mce/mode-names.h>
+#include <mce/dbus-names.h>
+#endif
+#endif
+#ifdef QT_SCREENSAVER_HANDLING
+#ifdef Q_WS_MAEMO_5
+#include <QtMaemo5/QtMaemo5>
+#include <QSystemScreenSaver>
+#endif
+#endif
+
 #define DEBUG_OUTPUT
 #undef DEBUG_OUTPUT
 
+/**
+Globals
+*/
+
+/**
+Implementation
+*/
+
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent)
 {
   snprintf(mainButtonStartText,BUFSIZ-1,
-           "&Start\n\n"
-           "If this program is used uncautiously\n"
-           "you could break your device physically.\n"
-           "Always be sure that you use this\n"
-           "software and the corresponding\n"
-           "hardware in a way that the hardware\n"
-           "won't get damaged."
+           "&Start"
            );
   this->setupUi();
   fsExitButton = new FullScreenExitButton(this);
@@ -59,11 +75,9 @@ MainWindow::MainWindow(QWidget *parent) :
   timerRefreshTimeMs = 100;
 
   connect(actionReset, SIGNAL(triggered()), this , SLOT(resetProgram()));
-  connect(actionSimulated_click, SIGNAL(triggered()), this , SLOT(mainButtonHandler()));
   connect(actionPause, SIGNAL(triggered()), this , SLOT(pauseCounting()));
   connect(actionStartStopMode, SIGNAL(triggered()), this, SLOT(toggleStartStopMode()));
 
-  connect(actionSave_full_list, SIGNAL(triggered()), this , SLOT(saveToFile()));
   connect(actionEnable_full_date, SIGNAL(triggered()), this , SLOT(toggleFullDate()));
   connect(actionEnable_time_and_date, SIGNAL(triggered()), this , SLOT(toggleTimeDate()));
   connect(actionShow_full_list, SIGNAL(triggered()), this , SLOT(showFullList()));
@@ -72,6 +86,10 @@ MainWindow::MainWindow(QWidget *parent) :
   connect(actionResetFs, SIGNAL(triggered()), this , SLOT(resetProgramAndFullscreen()));
   connect(actionChangeNumberOfLines, SIGNAL(triggered()), this, SLOT(changeNumberOfLines()));
   connect(actionChangeFontSize, SIGNAL(triggered()), this, SLOT(changeFontSize()));
+  connect(actionUseDeltaTime, SIGNAL(triggered()), this, SLOT(toggleUseDeltaTime()));
+#ifdef Q_WS_MAEMO_5
+  connect(actionDisableScreensaver, SIGNAL(triggered()), this, SLOT(toggleDisableScreensaver()));
+#endif
 
   connect(actionAbout, SIGNAL(triggered()), this , SLOT(about()));
 
@@ -80,11 +98,20 @@ MainWindow::MainWindow(QWidget *parent) :
   changeNumberOfLines(8);
   changeFontSize(30);
   isStartStopModeActive = false;
+  useDeltaTime = false;
   resetProgram();
+#ifdef Q_WS_MAEMO_5
+  path = "/home/user/MyDocs/.push-it.rc";
+#else
+  path = QDir::homePath() + "/.push-it.rc";
+#endif
+  loadFile();
+  resetUi();
 }
 
 MainWindow::~MainWindow()
 {
+  saveFile();
 }
 
 int MainWindow::updateTime()
@@ -132,9 +159,9 @@ void MainWindow::mainButtonRefresh()
 {
   updateTime();
   QString latest = generateHistoryString();
+  QString header = getHeaderLine();
   QString string = completeString.remove(mainButtonStartText);
   QStringList lines;
-  QString header = getHeaderLine();
 
   /* timer handling */
   if(NULL != timer)
@@ -152,9 +179,9 @@ void MainWindow::mainButtonRefresh()
     }
   }
 
+  mainButtonRefreshTextOnly();
   if(1 == hitCount)
   {
-    mainButtonRefreshTextOnly();
     return;
   }
   lines = string.split("\n");
@@ -203,10 +230,16 @@ QString MainWindow::generateHistoryString()
   QString result;
   char tmp[BUFSIZ];
   std::string previousStr, lastStr, firstStr;
+  double lastToPrev = 0;
+  double lastToStart = 0;
 
-  previousStr = overallTime.getPreviousTimeString();
+  //do all time queries at the beginning - to keep the delta of the whole
+  //application low
   lastStr = overallTime.getLastTimeString();
+  previousStr = overallTime.getPreviousTimeString();
   firstStr = overallTime.getStartTimeString();
+  lastToPrev = overallTime.getDeltaLastToPrev();
+  lastToStart =  overallTime.getDeltaLastToStart();
 
    snprintf(tmp,BUFSIZ-1,
       "\n"
@@ -216,9 +249,9 @@ QString MainWindow::generateHistoryString()
       "∑ %.3lfs "
       "Avg %.3lfs"
       ,
-      overallTime.getDeltaLastToPrev(),
-      overallTime.getDeltaLastToStart(),
-      overallTime.getDeltaLastToStart()/(hitCount-1)
+      lastToPrev,
+      lastToStart,
+      lastToStart/(hitCount-1)
       );
 
   result = tr(tmp);
@@ -242,10 +275,8 @@ int MainWindow::resetUi()
 {
   this->mainButton->setText(tr(mainButtonStartText));
   this->actionPause->setText(tr("&Pause"));
-  this->actionEnable_full_date->setDisabled(true);
 
   completeString = this->mainButton->text();
-  timeOutput = false;
 
   return EXIT_SUCCESS;
 }
@@ -295,20 +326,17 @@ void MainWindow::mainButtonTimeoutUpdate()
 
   QString string = this->mainButton->text();
   QStringList lines = string.split("\n");
+  QString header = getHeaderLine();
 
   if(lines.length() >= 1)
   {
-    lines[0] = getHeaderLine();
+    lines[0] = header;
   }
   else
   {
     assert(0 && "Lines are missing");
   }
   //update device
-#if 0
-//#ifdef Q_WS_MAEMO_5
-  osso_display_state_on();
-#endif
   //update ui
   this->mainButton->setText(tr(lines.join("\n").toStdString().c_str()));
 
@@ -316,7 +344,7 @@ void MainWindow::mainButtonTimeoutUpdate()
   lines = completeString.split("\n");
   if(lines.length() >= 1)
   {
-    lines[0] = getHeaderLine();
+    lines[0] = header;
   }
   completeString = lines.join("\n");
 }
@@ -326,10 +354,20 @@ QString MainWindow::getHeaderLine()
   QString headerLine;
   std::stringstream sstr;
 
-  double runTime = overallTime.getDeltaNowToStart();
   double time = 0;
   int hours = 0;
   int min = 0;
+  double runTime = 0;
+
+  //get the time
+  if(useDeltaTime)
+  {
+    runTime = overallTime.getDeltaNowToLast();
+  }
+  else
+  {
+    runTime = overallTime.getDeltaNowToStart();
+  }
 
   sstr << "#" << hitCount << " ";
   sstr << std::setfill('0');
@@ -342,7 +380,7 @@ QString MainWindow::getHeaderLine()
   sstr.setf(std::ios::fixed);
   sstr.setf(std::ios::showpoint);
   sstr.precision(1);
-  sstr << time << " "; //seconds
+  sstr << std::setw(4) << time << " "; //seconds
   if(true == timeOutput)
   {
     sstr << "#0 " << overallTime.getStartTimeString();
@@ -354,9 +392,9 @@ QString MainWindow::getHeaderLine()
 
 void MainWindow::saveToFile()
 {
-  ShowFullListDialog *listHander;
-  listHander = new ShowFullListDialog(0,completeString);
-  listHander->save();
+  ShowFullListDialog *listHandler;
+  listHandler = new ShowFullListDialog(0,completeString);
+  listHandler->save();
 }
 
 int MainWindow::toggleActionPause()
@@ -383,11 +421,11 @@ void MainWindow::toggleFullDate()
 {
   if(overallTime.isDateForStringsEnabled())
   {
-    overallTime.disableDateForStrings();
+    overallTime.setDateForStrings(false);
   }
   else
   {
-    overallTime.enableDateForStrings();
+    overallTime.setDateForStrings(true);
   }
 }
 
@@ -407,33 +445,48 @@ void MainWindow::toggleTimeDate()
 
 void MainWindow::about()
 {
-  AboutDialog *pa = new AboutDialog;
-  QTextBrowser *examples = new QTextBrowser;
-  examples->setOpenExternalLinks(true);
-  examples->setHtml(
-      "<p><b><a href =\"http://sites.google.com/site/markusscharnowski/n/pushit/real-life-examples\">Examples website with videos and pictures.</a></b><p>"
+  static AboutDialog *pa = NULL;
 
-      "<p>Excerpt:</p>"
+  if(NULL == pa)
+  {
+    pa = new AboutDialog;
+    QTextBrowser *examples = new QTextBrowser;
+    examples->setOpenExternalLinks(true);
+    examples->setHtml(
+        "<p><b><a href =\"http://sites.google.com/site/markusscharnowski/n/pushit/real-life-examples\">Examples website with videos and pictures.</a></b></p>"
+        "<p>"
+        "<b>Warning to be read, if the examples are followed:</b><br>"
+        "If this program is used uncautiously you could break your device physically. Always be sure that you use this software and the corresponding hardware in a way that the hardware won't get damaged."
+        "</p>"
+        "<p><b>Excerpt:</b></p>"
+        "<p><b>Pull ups</b></p>"
+        "<p>Place the phone add the position where you are in the highest position, so you can hit it with your nose. In my case I mount the Nokia N900 above a door with the help of some tesa-strips. I also tried it without tesa-strips but after some pushes on the N900 I was too anxious that it could fall down on the floor. So I recommend some safety mechanism to have fun with your device now and in the future. Every time you pulling yourself up, you touch the screen of the N900 with your nose. So you will always know how many pull ups you have done.</p>"
 
-      "<p><b>Pull ups</b></p>"
-      "<p>Place the phone add the position where you are in the highest position, so you can hit it with your nose. In my case I mount the Nokia N900 above a door with the help of some tesa-strips. I also tried it without tesa-strips but after some pushes on the N900 I was too anxious that it could fall down on the floor. So I recommend some safety mechanism to have fun with your device now and in the future. Every time you pulling yourself up, you touch the screen of the N900 with your nose. So you will always know how many pull ups you have done.</p>"
+        "<p><b>Push ups</b></p>"
+        "<p>Place the smartphone just below your nose so you can hit it with the nose when in the lowest position. And then start pushing up.</p>"
 
-      "<p><b>Push ups</b></p>"
-      "<p>Place the smartphone just below your nose so you can hit it with the nose when in the lowest position. And then start pushing up.</p>"
+        "<p><b>Crunches</b></p>"
+        "Doing crunches is a tiny bit more tricky. You have to go into your crunching position (laying on your back, feet up) and place your phone behind your head. Positioned well, you will be able to touch your phone with one of your thumbs every time you are going down (assuming you fold your hands behind your head when doing crunches)."
 
-      "<p><b>Crunches</b></p>"
-      "Doing crunches is a tiny bit more tricky. You have to go into your crunching position (laying on your back, feet up) and place your phone behind your head. Positioned well, you will be able to touch your phone with one of your thumbs every time you are going down (assuming you fold your hands behind your head when doing crunches)."
-
-      "<p><b>Lower back exercise</b></p>"
-      "<p>Place the phone just below your nose so you can hit it with the nose. I don't know how this exercise is called - if you know it, please let me know it too.<br>"
-      "To execute this exercise I lay myself on some pillows on a bench. My legs will get support by a table. The exercise itself is moving you upper body down to the phone and up again till your back is strait like when your are standing on your feet.</p>"
-      );
-
-  pa->setProgramName(windowTitle());
-  pa->setProgramUrl("http://sites.google.com/site/markusscharnowski/n/pushit");
-  pa->tabs->insertTab(5,examples,tr("&Examples"));
-  pa->setMinimumHeight(400);
+        "<p><b>Lower back exercise</b></p>"
+        "<p>Place the phone just below your nose so you can hit it with the nose. I don't know how this exercise is called - if you know it, please let me know it too.<br>"
+        "To execute this exercise I lay myself on some pillows on a bench. My legs will get support by a table. The exercise itself is moving you upper body down to the phone and up again till your back is strait like when your are standing on your feet.</p>"
+        );
 
+    QString name = releaseInfo.getPackageNameQ() + " " + releaseInfo.getPackageVersionQ();
+    pa->setProgramName(name);
+    pa->setProgramDate(releaseInfo.getPackageDateQ());
+    pa->setProgramUrl("http://sites.google.com/site/markusscharnowski/n/pushit");
+    pa->tabs->insertTab(5,examples,tr("&Examples"));
+    pa->setMinimumHeight(400);
+    pa->setFeedbackHtmlText(
+        "<p>Do you have ideas for improving the program? You want a specific functionality? "
+        "You have found a bug?</p>"
+        "<p><a href=\"http://code.google.com/p/push-it/issues/list\">Bugtracker</a></p>"
+        "<p>Email <a href=\"mailto:markus.scharnowski@gmail.com?subject=SW Feedback " + windowTitle() +
+        " &body=Hello Markus,\">Feedback</a></p>"
+        );
+  }
   pa->show();
 }
 
@@ -449,13 +502,11 @@ void MainWindow::showFullScreenHandler()
   if (isFullScreen)
   {
     showNormal();
-//    this->action_Fullscreen->setText(tr("&Fullscreen"));
   }
   else
   {
     showFullScreen();
     fsExitButton->show();
-//    this->action_Fullscreen->setText(tr("&Disable Fullscreen"));
   }
 }
 
@@ -508,9 +559,6 @@ void MainWindow::setupUi()
   actionReset = new QAction(this);
   actionReset->setObjectName(QString::fromUtf8("actionReset"));
 
-  actionSimulated_click = new QAction(this);
-  actionSimulated_click->setObjectName(QString::fromUtf8("actionSimulated_click"));
-
   actionPause = new QAction(this);
   actionPause->setObjectName(QString::fromUtf8("actionPause"));
 
@@ -521,9 +569,6 @@ void MainWindow::setupUi()
   actionShow_full_list = new QAction(this);
   actionShow_full_list->setObjectName(QString::fromUtf8("actionShow_full_list"));
 
-  actionSave_full_list = new QAction(this);
-  actionSave_full_list->setObjectName(QString::fromUtf8("actionSave_full_list"));
-
   actionAbout = new QAction(this);
   actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
 
@@ -548,6 +593,16 @@ void MainWindow::setupUi()
   actionChangeFontSize = new QAction(this);
   actionChangeFontSize->setObjectName(QString::fromUtf8("actionChangeFontSize"));
 
+  actionUseDeltaTime= new QAction(this);
+  actionUseDeltaTime->setObjectName(QString::fromUtf8("actionUseDeltaTime"));
+  actionUseDeltaTime->setCheckable(true);
+
+#ifdef Q_WS_MAEMO_5
+  actionDisableScreensaver = new QAction(this);
+  actionDisableScreensaver->setObjectName(QString::fromUtf8("actionDisableScreensaver"));
+  actionDisableScreensaver->setCheckable(true);
+#endif
+
   /* menu */
   menuBar = new QMenuBar(this);
   menuBar->setObjectName(QString::fromUtf8("menuBar"));
@@ -568,18 +623,20 @@ void MainWindow::setupUi()
   menuBar->addAction(menuHelp->menuAction());
   menuPush_It_Menu->addAction(actionReset);
   menuPush_It_Menu->addAction(actionPause);
-  menuPush_It_Menu->addAction(actionSimulated_click);
   menuPush_It_Menu->addAction(actionStartStopMode);
   menuHelp->addAction(actionAbout);
   menuData->addAction(actionEnable_time_and_date);
   menuData->addAction(actionEnable_full_date);
   menuData->addSeparator();
-  menuData->addAction(actionSave_full_list);
   menuData->addAction(actionShow_full_list);
   menuView->addAction(action_Fullscreen);
   menuView->addAction(actionResetFs);
   menuView->addAction(actionChangeNumberOfLines);
   menuView->addAction(actionChangeFontSize);
+  menuView->addAction(actionUseDeltaTime);
+#ifdef Q_WS_MAEMO_5
+  menuView->addAction(actionDisableScreensaver);
+#endif
 
   retranslateUi();
 
@@ -588,14 +645,12 @@ void MainWindow::setupUi()
 
 void MainWindow::retranslateUi()
 {
-  this->setWindowTitle(QApplication::translate("MainWindow", "Push It!", 0, QApplication::UnicodeUTF8));
+  this->setWindowTitle(QApplication::translate("MainWindow", releaseInfo.getPackageName().c_str(), 0, QApplication::UnicodeUTF8));
   actionReset->setText(QApplication::translate("MainWindow", "&Reset", 0, QApplication::UnicodeUTF8));
-  actionSimulated_click->setText(QApplication::translate("MainWindow", "Push &it!", 0, QApplication::UnicodeUTF8));
   actionPause->setText(QApplication::translate("MainWindow", "&Pause", 0, QApplication::UnicodeUTF8));
   actionStartStopMode->setText(QApplication::translate("MainWindow", "&Start+Pause Mode", 0, QApplication::UnicodeUTF8));
 
-  actionShow_full_list->setText(QApplication::translate("MainWindow", "Show full &list", 0, QApplication::UnicodeUTF8));
-  actionSave_full_list->setText(QApplication::translate("MainWindow", "&Save full list", 0, QApplication::UnicodeUTF8));
+  actionShow_full_list->setText(QApplication::translate("MainWindow", "Show+save full &list", 0, QApplication::UnicodeUTF8));
   actionEnable_full_date->setText(QApplication::translate("MainWindow", "Enable &full date", 0, QApplication::UnicodeUTF8));
   actionEnable_time_and_date->setText(QApplication::translate("MainWindow", "Enable &time and date", 0, QApplication::UnicodeUTF8));
 
@@ -603,8 +658,11 @@ void MainWindow::retranslateUi()
   actionResetFs->setText(QApplication::translate("MainWindow", "&Reset+Fullscreen", 0, QApplication::UnicodeUTF8));
   actionChangeNumberOfLines->setText(QApplication::translate("MainWindow", "&Lines", 0, QApplication::UnicodeUTF8));
   actionChangeFontSize->setText(QApplication::translate("MainWindow", "Font &size", 0, QApplication::UnicodeUTF8));
-
+  actionUseDeltaTime->setText(QApplication::translate("MainWindow", "Show delta &time", 0, QApplication::UnicodeUTF8));
   actionAbout->setText(QApplication::translate("MainWindow", "&About", 0, QApplication::UnicodeUTF8));
+#ifdef Q_WS_MAEMO_5
+  actionDisableScreensaver->setText(QApplication::translate("MainWindow", "&Disable Screensaver", 0, QApplication::UnicodeUTF8));
+#endif
 
   mainButton->setText(QApplication::translate("MainWindow", "Start", 0, QApplication::UnicodeUTF8));
 
@@ -686,6 +744,7 @@ void MainWindow::changeFontSize(int size)
     return;
   }
 
+  fontSize = size;
   QString actionText = actionChangeFontSize->text();
   actionText = "Font &size (";
   actionText += QString::number(size);
@@ -702,13 +761,22 @@ void MainWindow::mainButtonRefreshTextOnly()
 {
   QString string = completeString;
   QStringList lines;
+  QString header = getHeaderLine();
 
   if(1 == hitCount)
   {
-    string = getHeaderLine();
+    string = header;
   }
 
   lines = string.split("\n");
+  //only change the first line if it is not the inital string
+  if(string.indexOf("Start") < 0)
+  {
+    if(lines.length() > 0)
+    {
+      lines[0] = header;
+    }
+  }
 
   /* adjust the total number of lines of the button */
   if(lines.length() > maximumNumberOfLines)
@@ -749,3 +817,236 @@ void MainWindow::toggleStartStopMode()
   }
   return;
 }
+
+#ifdef Q_WS_MAEMO_5
+void MainWindow::toggleDisableScreensaver()
+{
+  static bool isDisabled = false;
+#ifdef QT_SCREENSAVER_HANDLING
+  static QtMobility::QSystemScreenSaver *saver = NULL;
+#endif
+
+  if(false == isDisabled)
+  {
+#ifdef MCE_SCREENSAVER_HANDLING
+    QDBusConnection::systemBus().call(QDBusMessage::createMethodCall(MCE_SERVICE, MCE_REQUEST_PATH,
+                                                                     MCE_REQUEST_IF, MCE_PREVENT_BLANK_REQ));
+#endif
+#ifdef QT_SCREENSAVER_HANDLING
+    saver = new QtMobility::QSystemScreenSaver();
+    saver->setScreenSaverInhibit();
+#endif
+    isDisabled = true;
+  }
+  else
+  {
+#ifdef MCE_SCREENSAVER_HANDLING
+    //no idea yet
+#endif
+#ifdef QT_SCREENSAVER_HANDLING
+    saver->deleteLater();
+    saver = NULL;
+#endif
+    isDisabled = false;
+  }
+}
+#endif
+
+void MainWindow::toggleUseDeltaTime()
+{
+  if(true == useDeltaTime)
+  {
+    useDeltaTime = false;
+  }
+  else
+  {
+    useDeltaTime = true;
+  }
+}
+
+int MainWindow::saveFile()
+{
+  std::ofstream file;
+  file.open(path.toStdString().c_str());
+  if(!file.is_open())
+  {
+#ifdef DEBUG_OUTPUT
+    std::cout << "No File" << path.toStdString() << std::endl;
+#endif
+    return EXIT_FAILURE;
+  }
+
+  sfm = getSfm();
+  if(NULL == sfm)
+  {
+    return EXIT_FAILURE;
+  }
+
+  for(int i = 0; sfm[i].getFunction != NULL; i++)
+  {
+    file << sfm[i].string.toStdString() << " " << ((this->*(sfm[i].getFunction))()) << std::endl;
+  }
+  file.close();
+  return EXIT_SUCCESS;
+}
+
+int MainWindow::loadFile()
+{
+  std::ifstream file;
+  file.open(path.toStdString().c_str());
+  if(!file.is_open())
+  {
+#ifdef DEBUG_OUTPUT
+    std::cout << "No File" << path.toStdString() << std::endl;
+#endif
+    return EXIT_FAILURE;
+  }
+
+  StringFunctionMap *sfm = getSfm();
+  if(NULL == sfm)
+  {
+    return EXIT_FAILURE;
+  }
+
+  try
+  {
+    std::string tmp;
+    while(std::getline(file,tmp))
+    {
+      for(int i = 0; sfm[i].getFunction != NULL; i++)
+      {
+        size_t found = tmp.find(sfm[i].string.toStdString());
+        if(found != std::string::npos)
+        {
+          QString tmp2 = tmp.c_str();
+          QStringList helper = tmp2.split(" ");
+          if(helper.length() > 1)
+          {
+            bool ok;
+            int x = helper[1].toInt(&ok,10);
+            if(true == ok)
+            {
+#ifdef DEBUG_OUTPUT
+              std::cout << helper[0].toStdString() << " " << x << " " << (this->*(sfm[i].setFunction))(x) << std::endl;
+#else
+              (this->*(sfm[i].setFunction))(x);
+#endif
+              break;
+            }
+          }
+          break;
+        }
+      }
+    }
+  }
+  catch(std::ifstream::failure e)
+  {
+    if(!file.eof())
+      std::cerr << e.what() <<'\n';
+  }
+
+  return EXIT_SUCCESS;
+}
+
+/*
+Functions to get ui specific behavior flags
+*/
+
+int MainWindow::getNumberOfLines()
+{
+  return maximumNumberOfLines;
+}
+int MainWindow::getFontSize()
+{
+  return fontSize;
+}
+int MainWindow::getDeltaModeFlag()
+{
+  return useDeltaTime;
+}
+int MainWindow::getStartPauseFlag()
+{
+  return isStartStopModeActive;
+}
+int MainWindow::getShowTimeDateFlag()
+{
+  return timeOutput;
+}
+int MainWindow::getShowFullDateFlag()
+{
+  return overallTime.isDateForStringsEnabled();
+}
+
+/*
+Functions to set ui specific behavior flags
+*/
+
+int MainWindow::setNumberOfLines(int n)
+{
+  changeNumberOfLines(n);
+  return (maximumNumberOfLines);
+}
+int MainWindow::setFontSize(int n)
+{
+  changeFontSize(n);
+  return (fontSize);
+}
+int MainWindow::setDeltaModeFlag(int n)
+{
+  actionUseDeltaTime->setChecked(bool(n));
+  return (useDeltaTime = bool(n));
+}
+int MainWindow::setStartPauseFlag(int n)
+{
+  actionStartStopMode->setChecked(bool(n));
+  return (isStartStopModeActive = bool(n));
+}
+int MainWindow::setShowTimeDateFlag(int n)
+{
+  actionEnable_time_and_date->setChecked(bool(n));
+  if(n)
+  {
+    actionEnable_full_date->setEnabled(true);
+  }
+  else
+  {
+    actionEnable_full_date->setEnabled(false);
+  }
+  return (timeOutput = bool(n));
+}
+int MainWindow::setShowFullDateFlag(int n)
+{
+  overallTime.setDateForStrings(bool(n));
+  actionEnable_full_date->setChecked(bool(n));
+  return bool(n);
+}
+
+MainWindow::StringFunctionMap* MainWindow::getSfm()
+{
+  static StringFunctionMap sfmx[]=
+  {
+    {"lines",
+     &MainWindow::getNumberOfLines,
+     &MainWindow::setNumberOfLines},
+{"size",
+ &MainWindow::getFontSize,
+ &MainWindow::setFontSize},
+{"deltaMode",
+ &MainWindow::getDeltaModeFlag,
+ &MainWindow::setDeltaModeFlag},
+{"showTimeDate",
+ &MainWindow::getShowTimeDateFlag,
+ &MainWindow::setShowTimeDateFlag},
+{"showFullDate",
+ &MainWindow::getShowFullDateFlag,
+ &MainWindow::setShowFullDateFlag},
+{"startPauseMode",
+ &MainWindow::getStartPauseFlag,
+ &MainWindow::setStartPauseFlag},
+{"",
+ NULL,
+ NULL}
+  };
+
+  return sfmx;
+}
